pub struct DepthStencilState { /* private fields */ }Implementations
Sourceimpl DepthStencilState
impl DepthStencilState
pub fn new() -> Self
Sourcepub fn with_compare_op(self, value: CompareOp) -> Self
pub fn with_compare_op(self, value: CompareOp) -> Self
The comparison operator used for depth testing.
Sourcepub fn with_back_stencil_state(self, value: StencilOpState) -> Self
pub fn with_back_stencil_state(self, value: StencilOpState) -> Self
The stencil op state for back-facing triangles.
Sourcepub fn with_front_stencil_state(self, value: StencilOpState) -> Self
pub fn with_front_stencil_state(self, value: StencilOpState) -> Self
The stencil op state for front-facing triangles.
Sourcepub fn with_compare_mask(self, value: u8) -> Self
pub fn with_compare_mask(self, value: u8) -> Self
Selects the bits of the stencil values participating in the stencil test.
Sourcepub fn with_write_mask(self, value: u8) -> Self
pub fn with_write_mask(self, value: u8) -> Self
Selects the bits of the stencil values updated by the stencil test.
Sourcepub fn with_enable_depth_test(self, value: bool) -> Self
pub fn with_enable_depth_test(self, value: bool) -> Self
True enables the depth test.
Sourcepub fn with_enable_depth_write(self, value: bool) -> Self
pub fn with_enable_depth_write(self, value: bool) -> Self
True enables depth writes.
Sourcepub fn with_enable_stencil_test(self, value: bool) -> Self
pub fn with_enable_stencil_test(self, value: bool) -> Self
True enables the stencil test.