pub struct StencilOpState { /* private fields */ }Implementations
Sourceimpl StencilOpState
impl StencilOpState
pub fn new() -> Self
Sourcepub fn with_fail_op(self, value: StencilOp) -> Self
pub fn with_fail_op(self, value: StencilOp) -> Self
The action performed on samples that fail the stencil test.
Sourcepub fn with_pass_op(self, value: StencilOp) -> Self
pub fn with_pass_op(self, value: StencilOp) -> Self
The action performed on samples that pass the depth and stencil tests.
Sourcepub fn with_depth_fail_op(self, value: StencilOp) -> Self
pub fn with_depth_fail_op(self, value: StencilOp) -> Self
The action performed on samples that pass the stencil test and fail the depth test.
Sourcepub fn compare_op(self, value: CompareOp) -> Self
pub fn compare_op(self, value: CompareOp) -> Self
The comparison operator used in the stencil test.