RelativeMouseState

Struct RelativeMouseState 

pub struct RelativeMouseState { /* private fields */ }

Implementations

Source

impl RelativeMouseState

pub fn new(_e: &EventPump) -> RelativeMouseState

pub fn from_sdl_state(state: u32) -> RelativeMouseState

pub fn to_sdl_state(&self) -> u32

pub fn left(&self) -> bool

Returns true if the left mouse button is pressed.

Example
use sdl3::mouse::MouseButton;

fn is_a_pressed(e: &sdl3::EventPump) -> bool {
    e.mouse_state().left()
}
pub fn middle(&self) -> bool

Tests if the middle mouse button was pressed.

pub fn right(&self) -> bool

Tests if the right mouse button was pressed.

pub fn x1(&self) -> bool

Tests if the X1 mouse button was pressed.

pub fn x2(&self) -> bool

Tests if the X2 mouse button was pressed.

pub fn x(&self) -> f32

Returns the x coordinate of the state

pub fn y(&self) -> f32

Returns the y coordinate of the state

pub fn is_mouse_button_pressed(&self, mouse_button: MouseButton) -> bool

Returns true if the mouse button is pressed.

Example
use sdl3::mouse::MouseButton;

fn is_left_pressed(e: &sdl3::EventPump) -> bool {
    e.mouse_state().is_mouse_button_pressed(MouseButton::Left)
}
pub fn mouse_buttons(&self) -> MouseButtonIterator<'_>

Returns an iterator all mouse buttons with a boolean indicating if the scancode is pressed.

Example
use sdl3::mouse::MouseButton;
use std::collections::HashMap;

fn mouse_button_set(e: &sdl3::EventPump) -> HashMap<MouseButton, bool> {
    e.mouse_state().mouse_buttons().collect()
}

fn find_first_pressed(e: &sdl3::EventPump) -> bool {
    for (key,value) in mouse_button_set(e) {
        return value != false
    }
    false
}
pub fn pressed_mouse_buttons(&self) -> PressedMouseButtonIterator<'_>

Returns an iterator of pressed mouse buttons.

Example
use sdl3::mouse::MouseButton;
use std::collections::HashSet;

fn pressed_mouse_button_set(e: &sdl3::EventPump) -> HashSet<MouseButton> {
    e.mouse_state().pressed_mouse_buttons().collect()
}

fn newly_pressed(old: &HashSet<MouseButton>, new: &HashSet<MouseButton>) -> HashSet<MouseButton> {
    new - old
    // sugar for: new.difference(old).collect()
}